%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%This is the software to make the images for article:

%Requirements:
%   -change path into the path to your folder
%   -make sure the data are in the data folder
%   -make sure there is an image folder to save the images to
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

clc;
clear;
close all;

path = 'N:\tnw\NS\kuiperslab\Irina\writing_articles\article_polarization\open_data\';

datapath = strcat(path,'data\');
figurepath=strcat(path,'images\');

%%
%This software does the following:
%   -import information of spectra and intensity
%   -plot intensity maps for figure 1
%   -plot intensity maps for supplementary figure S1
%   -plot spectra for supplementary figure S1

%%
%Import all the spectra and intensity maps

stepX300K = 12.0; stepY300K = 8.0;  %calibration piezo V --> um
stepX4K = 2.5;  stepY4K = 1.5;  %calibration piezo V --> um

colors{1} = [0 1 0];
colors{2} = [0.5 0.5 0];
colors{3} = [1 0 0];
colors{4} = [0.5 0 0.5];
colors{5} = [0 0 1];

info300K_flake1valley = load(strcat(datapath,'Info_2802_nofit','.mat'));
info300K_flake2 = load(strcat(datapath,'Info_0303_flake2','.mat'));
info300K_flake78 = load(strcat(datapath,'Info_1405_flake78_nofit','.mat'));

info300K_561 = load(strcat(datapath,'Info_0203','.mat'));
info4K_561 = load(strcat(datapath,'Info_1003','.mat'));

background_broad = load(strcat(datapath,'background_grating2_700_1s_1accums_gain10.txt'));

%%
%Figure 1d
%Calibrate the axes V --> um
%Plot the intensity map
%300K, flake 1

axisX = linspace(stepX300K*info300K_flake1valley.sample_x595(2)/10,stepX300K*info300K_flake1valley.sample_x595(end-3)/10,length(info300K_flake1valley.sample_x595)-4);
axisY = linspace(stepY300K*info300K_flake1valley.sample_y595(1)/10,stepY300K*info300K_flake1valley.sample_y595(end)/10,length(info300K_flake1valley.sample_y595));

fg1 = figure(1); clf(fg1); set(gcf,'Color','w');

imagesc(axisX,axisY,info300K_flake1valley.Integrated(:,2:end-3))

colorbar; colormap parula; caxis([0 4.5e6])

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('300K, flake 1')

print(fg1,strcat(figurepath,'figure1d.png'),'-dpng');

%%
%Figure 1e
%Calibrate the axes V --> um
%Plot the intensity map
%300K, flake 2 (called flake 8 here)

axisX = linspace(stepX300K*info300K_flake78.sample_x{3}(1)/10,stepX300K*info300K_flake78.sample_x{3}(end)/10,length(info300K_flake78.sample_x{3}));
axisY = linspace(stepY300K*info300K_flake78.sample_y{3}(1)/10,stepY300K*info300K_flake78.sample_y{3}(end)/10,length(info300K_flake78.sample_y{3}));

fg2 = figure(2); clf(fg2); set(gcf,'Color','w');

imagesc(axisX,axisY,info300K_flake78.Integrated{3}(:,1:end))

colorbar; colormap parula

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('300K, flake 2')

print(fg2,strcat(figurepath,'figure1e.png'),'-dpng');

%%
%Figure 1f
%Plot the spectrum

fg3 = figure(3); clf(fg3); set(gcf,'Color','w');

plot(info300K_flake1valley.wavelength_broad595,info300K_flake1valley.Spectrum_broad595(:,14,8)-info300K_flake1valley.background_broad(:,3),'color',[0 0.5 1]);

xlim([580 700])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')

print(fg3,strcat(figurepath,'figure1f.png'),'-dpng');

%%
%Figure S1a
%Calibrate the axes V --> um
%Plot the intensity map
%300K, flake 1, 561nm excitation

axisX = linspace(stepX300K*info300K_561.sample_x561(1)/10,stepX300K*info300K_561.sample_x561(end)/10,length(info300K_561.sample_x561));
axisY = linspace(stepY300K*info300K_561.sample_y561(1)/10,stepY300K*info300K_561.sample_y561(end)/10,length(info300K_561.sample_y561));

pointY = [25 21 18 15 11]; L = length(pointY);

fg4 = figure(4); clf(fg4); set(gcf,'Color','w');

imagesc(axisX,axisY,info300K_561.Maxima561_A)
hold on
for ii = 1:L
    plot(axisX(12),axisY(pointY(ii)),'*','color',colors{ii},'MarkerSize',20,'LineWidth',3)
    hold on
end

caxis([0 1e4]); colorbar

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('300K, flake 1')

print(fg4,strcat(figurepath,'figureS1a.png'),'-dpng');

%%
%Figure S1b
%Calibrate the axes V --> um
%Plot the intensity map
%300K, flake 2 intensity map

axisX = linspace(stepX300K*info300K_flake78.sample_x{3}(1)/10,stepX300K*info300K_flake78.sample_x{3}(end)/10,length(info300K_flake78.sample_x{3}));
axisY = linspace(stepY300K*info300K_flake78.sample_y{3}(1)/10,stepY300K*info300K_flake78.sample_y{3}(end)/10,length(info300K_flake78.sample_y{3}));

pointY = [45 38 30 24 18]; L = length(pointY);

fg5 = figure(5); clf(fg5); set(gcf,'Color','w');

imagesc(axisX,axisY,info300K_flake78.Maxima{3}(:,1:end))
hold on
for ii = 1:L
    plot(axisX(12),axisY(pointY(ii)),'*','color',colors{ii},'MarkerSize',20,'LineWidth',3)
end

colorbar; colormap parula

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('300K, flake 2')

print(fg5,strcat(figurepath,'figureS1b.png'),'-dpng');

%%
%Figure S1c
%Calibrate the axes V --> um
%Plot the intensity map
%300K, flake 3

axisX = linspace(stepX300K*info300K_flake2.sample_x595_2(1)/10,stepX300K*info300K_flake2.sample_x595_2(end)/10,length(info300K_flake2.sample_x595_2));
axisY = linspace(stepY300K*info300K_flake2.sample_y595_2(1)/10,stepY300K*info300K_flake2.sample_y595_2(end)/10,length(info300K_flake2.sample_y595_2));

pointY = [24 18 12 8 3]; L = length(pointY);

fg6 = figure(6); clf(fg6); set(gcf,'Color','w');

imagesc(axisX,axisY,info300K_flake2.Maxima_broad595_2(:,1:end))
hold on
for ii = 1:L
    plot(axisX(18),axisY(pointY(ii)),'*','color',colors{ii},'MarkerSize',20,'LineWidth',3)
    hold on
end

colorbar; colormap parula

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('300K, flake 3')

print(fg6,strcat(figurepath,'figureS1c.png'),'-dpng');

%%
%Figure S1d
%Calibrate the axes V --> um
%Plot the intensity map
%300K, flake 4

axisX = linspace(stepX300K*info300K_flake78.sample_x{2}(1)/10,stepX300K*info300K_flake78.sample_x{2}(end)/10,length(info300K_flake78.sample_x{2}));
axisY = linspace(stepY300K*info300K_flake78.sample_y{2}(1)/10,stepY300K*info300K_flake78.sample_y{2}(end)/10,length(info300K_flake78.sample_y{2}));

pointY = [25 21 15 8 3]; L = length(pointY);

fg7 = figure(7); clf(fg7); set(gcf,'Color','w');

imagesc(axisX,axisY,info300K_flake78.Maxima{2}(:,1:end))
hold on
for ii = 1:L
    plot(axisX(13),axisY(pointY(ii)),'*','color',colors{ii},'MarkerSize',20,'LineWidth',3)
    hold on
end

colorbar; colormap parula

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('300K, flake 4')

print(fg7,strcat(figurepath,'figureS1d.png'),'-dpng');

%%
%Figure S1e
%Plot the five spectra
%300K, flake 1, 561nm excitation

pointY = [25 21 18 15 11]; L = length(pointY);

fg8 = figure(8); clf(fg8); set(gcf,'Color','w');

for ii = 1:L
    plot(info300K_561.wavelength_broad561,info300K_561.Spectrum_broad561(:,pointY(ii),12)-background_broad(:,3),'color',colors{ii})
    hold on
end

xlim([560 840])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')
title('300K, flake 1')

print(fg8,strcat(figurepath,'figureS1e.png'),'-dpng');

%%
%Figure S1f
%Plot the five spectra
%300K, flake 2 spectra

pointY = [45 38 30 24 18];

fg9 = figure(9); clf(fg9); set(gcf,'Color','w');

for ii = 1:L
    plot(info300K_flake78.wavelength{3},info300K_flake78.Spectrum{3}(:,pointY(ii),12),'color',colors{ii});
    hold on
end

xlim([560 840])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')
title('300K, flake 2')

print(fg9,strcat(figurepath,'figureS1f.png'),'-dpng');

%%
%Figure S1g
%Plot the five spectra
%300K, flake 3

pointY = [24 18 12 8 3]

fg10 = figure(10); clf(fg10); set(gcf,'Color','w');

for ii = 1:L
    pl=plot(info300K_flake2.wavelength_broad595_2,info300K_flake2.Spectrum_broad595_2(:,pointY(ii),18),'color',colors{ii});
    hold on
end

xlim([560 840])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')
title('300K, flake 3')

print(fg10,strcat(figurepath,'figureS1g.png'),'-dpng');

%%
%Figure S1h
%Plot the five spectra
%300K, flake 4

pointY = [25 21 15 8 3]; L = length(pointY);

fg11 = figure(11); clf(fg11); set(gcf,'Color','w');

for ii = 1:L
    plot(info300K_flake78.wavelength{2},info300K_flake78.Spectrum{2}(:,pointY(ii),13),'color',colors{ii});
    hold on
end

xlim([560 840])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')
title('300K, flake 4')

print(fg11,strcat(figurepath,'figureS1h.png'),'-dpng');

%%
%Figure S1l
%Plot the five spectra
%4K, flake 1, 595nm excitation

number = 4;

fg12 = figure(12); clf(fg12); set(gcf,'Color','w');

pointY = [25 21 16 12 7]; L = length(pointY);

for ii = 1:L
    plot(info4K_561.wavelengthA,info4K_561.SpectrumA(:,pointY(ii),9)-background_broad(:,3),'color',colors{ii})
    hold on
end

xlim([560 840])
ylim([-1e3 4e4])
xlabel('wavelength (nm)')
ylabel('I (counts/s)')
title('4K, flake 1')

print(fg12,strcat(figurepath,'figureS1l.png'),'-dpng');




