%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%This is the software to make the images for article

%Requirements:
%   -change path into the path to your folder
%   -make sure the program vivid is in this folder (for the colormap)
%   -make sure the data are in the data folder
%   -make sure there is an image folder to save the images to
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
clc;
clear;
close all;

path = 'N:\tnw\NS\kuiperslab\Irina\writing_articles\article_polarization\open_data\';

datapath = strcat(path,'data\');
figurepath=strcat(path,'images\');

%%
%This software does the following:
%   import information of fitted spectra and valley polarization and
%   coherence of flake 3 and 4 (here called 7 and 2)
%   plot subfigures of figure S5 in the supplementary 

%%
%Import all the fitted spectra and the results of the fit

stepX4K = 2.5; stepY4K = 1.5; %calibration piezo V --> um

info4K_flake27 = load(strcat(datapath,'Info_1906_flake782','.mat'));
info4K_flake7valley = load(strcat(datapath,'Info_0701_flake7_fits','.mat'));
info4K_flake2valley = load(strcat(datapath,'Info_0702_flake2_fits','.mat'));

info4K_flake7 = load(strcat(datapath,'info4K_flake7_fit.mat'));
info4K_flake2 = load(strcat(datapath,'info4K_flake2_fit.mat'));

%%
%This is needed to make the blue-red colormap for valley polarization

level = 52; n = ceil(level/2);
cmap1 = [linspace(1, 1, n); linspace(0, 1, n); linspace(0, 1, n)]';
cmap2 = [linspace(1, 0, n); linspace(1, 0, n); linspace(1, 1, n)]';
cmap = [cmap1; cmap2(2:end, :)];
cmap=flip(cmap);

%%
%Figure S5a
%-Determine the axes using the calibration of V --> um
%-Plot the map of intensity of fl.3
%4K, flake 3

axisX = linspace(stepX4K*info4K_flake27.sample_x{5}(1)/10,stepX4K*info4K_flake27.sample_x{5}(end)/10,length(info4K_flake27.sample_x{5}));
axisY = linspace(stepY4K*info4K_flake27.sample_y{5}(1)/10,stepY4K*info4K_flake27.sample_y{5}(end)/10,length(info4K_flake27.sample_y{5}));

fg1 = figure(1); clf(fg1); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake27.Maxima{5}(:,1:end))

colorbar; caxis([0 1.8e4]); colormap parula

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('Intensity flake 3')

print(fg1,strcat(figurepath,'figureS5a.png'),'-dpng');

%%
%Figure S5b
%-Determine the axes using the calibration of V --> um
%-Plot the map of valley polarization of fl.3
%4K, flake 3

axisX = linspace(stepX4K*info4K_flake2valley.sample_x{4}(1)/10,stepX4K*info4K_flake2valley.sample_x{4}(end)/10,length(info4K_flake2valley.sample_x{4}));
axisY = linspace(stepY4K*info4K_flake2valley.sample_y{4}(1)/10,stepY4K*info4K_flake2valley.sample_y{4}(end)/10,length(info4K_flake2valley.sample_y{4}));

fg2 = figure(2); clf(fg2); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake2valley.ValleyPol595_flake2_fit(:,1:end-1))

colorbar; colormap(vivid(cmap, [.5 .5])); caxis([0 0.8])

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('Valley polarization flake 3')

print(fg2,strcat(figurepath,'figureS5b.png'),'-dpng');

%%
%Figure S5c
%-Determine the axes using the calibration of V --> um
%-Plot the map of valley coherence of fl.3
%4K, flake 3

axisX = linspace(stepX4K*info4K_flake2.sample_x(1)/10,stepX4K*info4K_flake2.sample_x(end)/10,length(info4K_flake2.sample_x));
axisY = linspace(stepY4K*info4K_flake2.sample_y(1)/10,stepY4K*info4K_flake2.sample_y(end)/10,length(info4K_flake2.sample_y));

fg3 = figure(3); clf(fg3); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake2.coherence)

caxis([0 0.6]); colormap hot; colorbar;

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('Valley coherence flake 3')

print(fg3,strcat(figurepath,'figureS5c.png'),'-dpng');

%%
%Figure S5d
%-Determine the axes using the calibration of V --> um
%-Plot the map of intensity of fl.4
%4K, flake 4

axisX = linspace(stepX4K*info4K_flake27.sample_x{1}(1)/10,stepX4K*info4K_flake27.sample_x{1}(end)/10,length(info4K_flake27.sample_x{1}));
axisY = linspace(stepY4K*info4K_flake27.sample_y{1}(1)/10,stepY4K*info4K_flake27.sample_y{1}(end)/10,length(info4K_flake27.sample_y{1}));

fg4 = figure(4); clf(fg4); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake27.Maxima{1}(:,1:end))

colorbar; caxis([0 1.8e4]); colormap parula

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('Intensity flake 4')

print(fg4,strcat(figurepath,'figureS5d.png'),'-dpng');

%%
%Figure S5e
%-Determine the axes using the calibration of V --> um
%-Plot the map of valley polarization of fl.4
%4K, flake 4

axisX = linspace(stepX4K*info4K_flake7valley.sample_x{4}(1)/10,stepX4K*info4K_flake7valley.sample_x{4}(end)/10,length(info4K_flake7valley.sample_x{4}));
axisY = linspace(stepY4K*info4K_flake7valley.sample_y{4}(1)/10,stepY4K*info4K_flake7valley.sample_y{4}(end)/10,length(info4K_flake7valley.sample_y{4}));

fg5 = figure(5); clf(fg5); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake7valley.ValleyPol595_flake7_fit(:,1:end-1))

colorbar; colormap(vivid(cmap, [.5 .5])); caxis([0 0.8])

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('Valley polarization flake 4')

print(fg5,strcat(figurepath,'figureS5e.png'),'-dpng');

%%
%Figure S5f
%-Determine the axes using the calibration of V --> um
%-Plot the map of intensity of fl.4
%4K, flake 4

axisX = linspace(stepX4K*info4K_flake7.sample_x(1)/10,stepX4K*info4K_flake7.sample_x(end)/10,length(info4K_flake7.sample_x));
axisY = linspace(stepY4K*info4K_flake7.sample_y(1)/10,stepY4K*info4K_flake7.sample_y(end)/10,length(info4K_flake7.sample_y));

fg6 = figure(6); clf(fg6); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake7.coherence)

caxis([0 0.6]); colormap hot; colorbar;

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('Valley coherence flake 4')

print(fg6,strcat(figurepath,'figureS5f.png'),'-dpng');


