%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%This is the software to make the images for article

%Requirements:
%   -change path into the path to your folder
%   -make sure the program quarter_wave_matrix is in this folder
%   -make sure the data are in the data folder
%   -make sure there is an image folder to save the images to
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

clc;
clear;
close all;

path = 'N:\tnw\NS\kuiperslab\Irina\writing_articles\article_polarization\open_data\';

datapath = strcat(path,'data\');
figurepath=strcat(path,'images\');

%%
%This software does the following:
%   -import information of fitted spectra and fitted intensity-angle curves
%   -calculate average and standard deviation of valley coherence maps at
%   different temperatures
%   -plot subfigures of figure 4 in main text
%   -plot subfigures of figure S4 in the supplementary materials
%   -plot subfigures of figure S2 in the supplementary materials

%%
%Import all the fitted spectra and the results of the fit

temperatures = [4,100,200,300];

stepX300K = 12.0; stepY300K = 8.0; %calibration piezo V --> um
stepX200K = 7.5; stepY200K = 4.0; %calibration piezo V --> um
stepX100K = 6.0; stepY100K = 3.0;%calibration piezo V --> um
stepX4K = 2.5; stepY4K = 1.5;  %calibration piezo V --> um

info4K_flake582 = load(strcat(datapath,'info4K_flake8_fit.mat'));
info100K_flake285 = load(strcat(datapath,'info100K_flake8_fit.mat'));
info200K_flake82 =load(strcat(datapath,'info200K_flake8_fit.mat'));
info300K_flake285 =load(strcat(datapath,'info300K_flake8_fit.mat'));
info4K_flake175 = load(strcat(datapath,'info4K_flake1_fit.mat'));
info100K_flake517 = load(strcat(datapath,'info100K_flake1_fit.mat'));
info200K_flake715 = load(strcat(datapath,'info200K_flake1_fit.mat'));
info300K_flake1 = load(strcat(datapath,'info300K_flake1_fit.mat'));

info4K_flake1_linear = load(strcat(datapath,'Info_1103_flake1Linear_fits.mat'));

thorlabs = load(strcat(datapath,'thorlabs_waveplate.txt'));

%%
%Figure 4b
%Plot the spectra

pos1 = [8,6]; pos2 = [3,1];

fg1 = figure(1); clf(fg1); set(gcf,'Color','w');

plot(info4K_flake175.wavelength,info4K_flake175.Spectrum(:,1,pos1(1),pos1(2)),'color',[1 0.8 0]);
hold on
plot(info4K_flake175.wavelength,info4K_flake175.Spectrum(:,3,pos1(1),pos1(2)),'y');
hold on
plot(info4K_flake175.wavelength,info4K_flake175.Spectrum(:,1,pos2(1),pos2(2)),'r');
hold on
plot(info4K_flake175.wavelength,info4K_flake175.Spectrum(:,3,pos2(1),pos2(2)),'color',[1 0.8 0.8]);
hold off

xlim([580 700])

xlabel('wavelength (nm)');
ylabel('I (counts/s)');
legend('0 deg','45 deg','0 deg','45 deg')

print(fg1,strcat(figurepath,'figure4b.png'),'-dpng');

%%
%Figure 4c
%-import the specifications of the quarterwaveplate from thorlabs
%-using the equations in the Supplementary Materials, fit one of the intensity/angle curves
%-plot the curves and the fit

exciton = [612,615,620,629];        %based on 561nm laser measurements and average of fits on flake1

%Find out the retardance of the lambda/4 at the exciton wavelength at
%different temperatures
for ii = 1:length(exciton)
    [a,index]=min(abs(thorlabs(:,1)-exciton(ii)))
    thorlabs(index,1)
    retard_thorlabs(ii) = thorlabs(index,2)
end

theta = linspace(0,pi,100);

M_analizer = 0.5*[ 1, -1, 0, 0;...
                  -1,  1, 0, 0;...
                   0,  0, 0, 0;...
                   0,  0, 0, 0];
              
retardance = retard_thorlabs(1)*(2*pi);

data = squeeze(info4K_flake582.Integrated(1,:,4,3));
theta_data = info4K_flake582.Angles*pi/180;
               
% fit the data with a linear least square
% create the matrix
M = zeros(length(data),4);
for i_theta = 1:length(data)
    local_M = M_analizer * quarter_wave_matrix(retardance,theta_data(i_theta));
    M(i_theta,:) = local_M(1,:);
end
% linear least square fit
S_in = M \ data';

for i_theta = 1:length(theta)
    S_out = M_analizer * quarter_wave_matrix(retardance,theta(i_theta)) * S_in;
    fit_data(i_theta) = S_out(1);
end

%plot the data and fit
colors{1} = 'y';    colors{3} = 'g'; colors{5} = 'r'; colors{7} = 'b';
fg2 = figure(2); clf(fg2); set(gcf,'Color','w');

for ii = [1,3,5,7]
    pl{ii}=plot(info4K_flake582.Angles*pi/180,info4K_flake582.Integrated(1,:,4,ii)/max(info4K_flake582.Integrated(1,:,4,ii)),colors{ii});
    hold on
end
pl{2} = plot(theta,fit_data/max(fit_data),'k--');
hold off
 
ylim([0.6 1.0])

xticks([0 pi/4 pi/2 3*pi/4])
xticklabels({'0','\pi/4','\pi/2','3\pi/4'})

xlabel('angle of \lambda/4 (rad)');
ylabel('I_{normalized}');
legend([pl{3},pl{2}],{'data','fit'})

print(fg2,strcat(figurepath,'figure4c.png'),'-dpng');

%%
%Figure 4d
%-Determine the axes using the calibration of V --> um
%-Plot the map of valley coherence of fl.1

pos1 = [8,6];   pos2 = [3,1];   %positions of shown spectra

axisX = linspace(stepX4K*info4K_flake175.sample_x(1)/10,stepX4K*info4K_flake175.sample_x(end)/10,length(info4K_flake175.sample_x));
axisY = linspace(stepY4K*info4K_flake175.sample_y(1)/10,stepY4K*info4K_flake175.sample_y(end)/10,length(info4K_flake175.sample_y));

fg3 = figure(3); clf(fg3); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake175.coherence)
hold on
plot(axisX(pos1(2)),axisY(pos1(1)),'ok','markersize',15);
hold on
plot(axisX(pos2(2)),axisY(pos2(1)),'pk','markersize',15);
hold off

colorbar; colormap hot; caxis([0 0.55])

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')

print(fg3,strcat(figurepath,'figure4d.png'),'-dpng');


%%
%Figure 4e
%-Determine the axes using the calibration of V --> um
%-Plot the map of valley coherence of fl.2

axisX = linspace(stepX4K*info4K_flake582.sample_x(1)/10,stepX4K*info4K_flake582.sample_x(end)/10,length(info4K_flake582.sample_x));
axisY = linspace(stepY4K*info4K_flake582.sample_y(1)/10,stepY4K*info4K_flake582.sample_y(end)/10,length(info4K_flake582.sample_y));

colors{1} = 'y';    colors{3} = 'g'; colors{5} = 'r'; colors{7} = 'b';
markers{1} = 'p';   markers{3} = 'o'; markers{5} = 'o'; markers{7} = 'p';

fg4 = figure(4); clf(fg4); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake582.coherence)
hold on
for ii = [1,3,5,7]
    plot(axisX(ii),axisY(4),markers{ii},'color',colors{ii},'markerfacecolor',colors{ii},'markersize',15);
    hold on
end

colorbar; colormap hot; caxis([0 0.65])

xlabel('X (um)');set(gca,'Xdir','reverse')
ylabel('Y (um)');set(gca,'Ydir','normal')

print(fg4,strcat(figurepath,'figure4e.png'),'-dpng');

%%
coherence_middle = zeros(10,1);
coherence_sides = zeros(10,1);
coherence_rest = zeros(10,1);

coherence_std_middle = zeros(10,1);
coherence_std_sides = zeros(10,1);
coherence_std_rest = zeros(10,1);

%%
%Calculate the average of the valley coherence in the sides and middle of
%the flake
% T = 4K, laser = 595, quarterwaveplate on flake 2

number = 1;     %in this file
place = 3;      %in file where came from

[a,b] = size(info4K_flake582.coherence);

coherence_middle(number,:) = 0;
tellerM = 0;

coherence_sides(number,:) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        if info4K_flake582.Intens(jj,ii) > 1.2e5
            if info4K_flake582.Intens(jj,ii) < 2.6e5
                coherence_middle(number) = coherence_middle(number) + info4K_flake582.coherence(jj,ii);
                tellerM = tellerM + 1;
            else
                coherence_sides(number) = coherence_sides(number) + info4K_flake582.coherence(jj,ii);
                tellerZ = tellerZ + 1;                
            end
        end
    end
end        

coherence_middle(number) = coherence_middle(number)/tellerM;
coherence_sides(number) = coherence_sides(number)/tellerZ;

coherence_middle(number)
coherence_sides(number)

%%
%Calculate the standard deviation of the valley coherence in the sides and middle of
%the flake
% T = 4K, laser = 595, quarterwaveplate on flake 2

coherence_std_middle(number,:) = 0;
coherence_std_sides(number,:) = 0;

tellerM = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        if info4K_flake582.Intens(jj,ii) > 1.2e5
            if info4K_flake582.Intens(jj,ii) < 2.4e5
                coherence_std_middle(number) = coherence_std_middle(number) + abs(info4K_flake582.coherence(jj,ii)-coherence_middle(number));
                tellerM = tellerM + 1;
            else
                coherence_std_sides(number) = coherence_std_sides(number) + abs(info4K_flake582.coherence(jj,ii)-coherence_sides(number));
                tellerZ = tellerZ + 1;                
            end
        end
    end
end        
coherence_std_middle(number) = coherence_std_middle(number)/tellerM;
coherence_std_sides(number) = coherence_std_sides(number)/tellerZ;

coherence_std_middle(number)
coherence_std_sides(number)

%%
%Calculate the average of the valley coherence in the sides and middle of
%the flake
% T = 100K, laser = 595, quarterwaveplate on flake 2

number = 2;     %in this file
place = 3;      %in file where came from

[a,b] = size(info100K_flake285.coherence);

coherence_middle(number,:) = 0;
tellerM = 0;

coherence_sides(number,:) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        if info100K_flake285.Intens(jj,ii) > 0
            if info100K_flake285.Intens(jj,ii) < 4.5e5
                coherence_middle(number) = coherence_middle(number) + info100K_flake285.coherence(jj,ii);
                tellerM = tellerM + 1;
            else
                coherence_sides(number) = coherence_sides(number) + info100K_flake285.coherence(jj,ii);
                tellerZ = tellerZ + 1;                
            end
        end
    end
end        

coherence_middle(number) = coherence_middle(number)/tellerM;
coherence_sides(number) = coherence_sides(number)/tellerZ;

coherence_middle(number)
coherence_sides(number)

%%%Calculate the standard deviation of the valley coherence in the sides and middle of
%the flake
% T = 100K, laser = 595, quarterwaveplate on flake 2

coherence_std_middle(number,:) = 0;
coherence_std_sides(number,:) = 0;

tellerM = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        if info100K_flake285.Intens(jj,ii) > 0
            if info100K_flake285.Intens(jj,ii) < 4.5e5
                coherence_std_middle(number) = coherence_std_middle(number) + abs(info100K_flake285.coherence(jj,ii)-coherence_middle(number));
                tellerM = tellerM + 1;
            else
                coherence_std_sides(number) = coherence_std_sides(number) + abs(info100K_flake285.coherence(jj,ii)-coherence_sides(number));
                tellerZ = tellerZ + 1;                
            end
        end
    end
end        
coherence_std_middle(number) = coherence_std_middle(number)/tellerM;
coherence_std_sides(number) = coherence_std_sides(number)/tellerZ;

coherence_std_middle(number)
coherence_std_sides(number)

%%
%Calculate the average of the valley coherence in the sides and middle of
%the flake
% T = 200K, laser = 595, quarterwaveplate on flake 2

number = 3;     %in this file
place = 1;      %in file where came from

[a,b] = size(info200K_flake82.coherence);

coherence_middle(number,:) = 0;
tellerM = 0;

coherence_sides(number,:) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        take_middle_point = 0;
        if jj == 5 
            if ii == 7 | ii == 8 | ii == 9
                take_middle_point = 1;
            end
        elseif jj == 6 & ii == 8
            take_middle_point = 1;
        end
        
        if info200K_flake82.Intens(jj,ii) > 0 & take_middle_point == 0
            if info200K_flake82.Intens(jj,ii) < 2.6e5
                coherence_middle(number) = coherence_middle(number) + info200K_flake82.coherence(jj,ii);
                tellerM = tellerM + 1;
            else
                coherence_sides(number) = coherence_sides(number) + info200K_flake82.coherence(jj,ii);
                tellerZ = tellerZ + 1;                
            end
        end
    end
end        

coherence_middle(number) = coherence_middle(number)/tellerM;
coherence_sides(number) = coherence_sides(number)/tellerZ;

coherence_middle(number)
coherence_sides(number)

%%
%Calculate the standard deviation of the valley coherence in the sides and middle of
%the flake
% T = 200K, laser = 595, quarterwaveplate on flake 2

coherence_std_middle(number,:) = 0;
coherence_std_sides(number,:) = 0;

tellerM = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        take_middle_point = 0;
        if jj == 5 
            if ii == 7 | ii == 8 | ii == 9
                take_middle_point = 1;
            end
        elseif jj == 6 & ii == 8
            take_middle_point = 1;
        end
        
        if info200K_flake82.Intens(jj,ii) > 0 & take_middle_point == 0
            if info200K_flake82.Intens(jj,ii) < 2.6e5
                coherence_std_middle(number) = coherence_std_middle(number) + abs(info200K_flake82.coherence(jj,ii)-coherence_middle(number));
                tellerM = tellerM + 1;
            else
                coherence_std_sides(number) = coherence_std_sides(number) + abs(info200K_flake82.coherence(jj,ii)-coherence_sides(number));
                tellerZ = tellerZ + 1;                
            end
        end
    end
end        
coherence_std_middle(number) = coherence_std_middle(number)/tellerM;
coherence_std_sides(number) = coherence_std_sides(number)/tellerZ;

coherence_std_middle(number)
coherence_std_sides(number)

%%
%Calculate the average of the valley coherence in the sides and middle of
%the flake
% T = 300K, laser = 595, quarterwaveplate on flake 2

number = 4;     %in this file
place = 4;      %in file where came from

[a,b] = size(info300K_flake285.coherence);

coherence_middle(number,:) = 0;
tellerM = 0;

coherence_sides(number,:) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a        
        if info300K_flake285.Intens(jj,ii) > 9e4
            if info300K_flake285.Intens(jj,ii) < 1.5e5
                coherence_middle(number) = coherence_middle(number) + info300K_flake285.coherence(jj,ii);
                tellerM = tellerM + 1;
            else
                coherence_sides(number) = coherence_sides(number) + info300K_flake285.coherence(jj,ii);
                tellerZ = tellerZ + 1;                
            end
        end
    end
end        

coherence_middle(number) = coherence_middle(number)/tellerM;
coherence_sides(number) = coherence_sides(number)/tellerZ;

coherence_middle(number)
coherence_sides(number)

%%
%Calculate the standard deviation of the valley coherence in the sides and middle of
%the flake
% T = 300K, laser = 595, quarterwaveplate on flake 2

coherence_std_middle(number,:) = 0;
coherence_std_sides(number,:) = 0;

tellerM = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        if info300K_flake285.Intens(jj,ii) > 9e4
            if info300K_flake285.Intens(jj,ii) < 1.5e5
                coherence_std_middle(number) = coherence_std_middle(number) + abs(info300K_flake285.coherence(jj,ii)-coherence_middle(number));
                tellerM = tellerM + 1;
            else
                coherence_std_sides(number) = coherence_std_sides(number) + abs(info300K_flake285.coherence(jj,ii)-coherence_sides(number));
                tellerZ = tellerZ + 1;                
            end
        end
    end
end        
coherence_std_middle(number) = coherence_std_middle(number)/tellerM;
coherence_std_sides(number) = coherence_std_sides(number)/tellerZ;

coherence_std_middle(number)
coherence_std_sides(number)

%%
%Calculate the average of the valley coherence in the sides and middle of
%the flake
% T = 4K, laser = 595, quarterwaveplate on flake 1

number = 5;     %in this file
place = 6;      %in file where came from

[a,b] = size(info4K_flake175.coherence);

punt{1}=[6,7]; punt{2}=[6,8]; punt{3}=[7,7]; punt{4}=[7,8]; punt{5}=[6,9];
punt{6}=[7,9]; punt{7}=[6,10]; punt{8}=[6,11]; punt{9}=[6,12]; punt{10}=[7,6];
punt{11}=[8,6]; punt{12}=[9,6]; punt{13}=[5,6]; punt{14}=[10,6]; punt{15}=[6,5]; 
punt{16}=[7,5]; punt{17}=[5,5]; punt{18}=[5,4]; punt{19}=[6,4]; punt{20}=[5,3];
punt{21}=[4,3]; punt{22}=[4,2]; punt{23}=[3,1];

took_middle_point = 0;

coherence_middle(number,:) = 0;
tellerM = 0;

coherence_sides(number,:) = 0;
tellerZ = 0;

coherence_rest(number,:) = 0;
tellerR = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info4K_flake175.Intens(jj,ii) > 1e5
            if info4K_flake175.Intens(jj,ii) > 4.8e5
                coherence_sides(number) = coherence_sides(number) + info4K_flake175.coherence(jj,ii);
                tellerZ = tellerZ + 1; 
            else
                for yy = 1:length(punt)
                    if [ii,jj]==punt{yy}
                        coherence_middle(number) = coherence_middle(number) + info4K_flake175.coherence(jj,ii);
                        tellerM = tellerM + 1;
                        took_middle_point = 1
                    end
                end
                if took_middle_point == 0
                    coherence_rest(number) = coherence_rest(number) + info4K_flake175.coherence(jj,ii);
                    tellerR = tellerR + 1;                     
                end
            end
        end
    end
end        

coherence_middle(number) = coherence_middle(number)/tellerM;
coherence_sides(number) = coherence_sides(number)/tellerZ;
coherence_rest(number) = coherence_rest(number)/tellerR;

coherence_middle(number)
coherence_sides(number)
coherence_rest(number)

%%
%Calculate the standard deviation of the valley coherence in the sides and middle of
%the flake
% T = 4K, laser = 595, quarterwaveplate on flake 1

coherence_std_middle(number,:) = 0;
coherence_std_sides(number,:) = 0;

tellerM = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info4K_flake175.Intens(jj,ii) > 1e5
            if info4K_flake175.Intens(jj,ii) > 4.8e5
                coherence_std_sides(number) = coherence_std_sides(number) + abs(info4K_flake175.coherence(jj,ii)-coherence_sides(number));
                tellerZ = tellerZ + 1;
            else
                for yy = 1:length(punt)
                    if [ii,jj]==punt{yy}               
                        coherence_std_middle(number) = coherence_std_middle(number) + abs(info4K_flake175.coherence(jj,ii)-coherence_middle(number));
                        tellerM = tellerM + 1;
                    end
                end
                if took_middle_point == 0
                    coherence_std_rest(number) = coherence_std_rest(number) + abs(info4K_flake175.coherence(jj,ii)-coherence_rest(number));
                    tellerR = tellerR + 1;
                end
            end
        end
    end
end        
coherence_std_middle(number) = coherence_std_middle(number)/tellerM;
coherence_std_sides(number) = coherence_std_sides(number)/tellerZ;
coherence_std_rest(number) = coherence_std_rest(number)/tellerR;

coherence_std_middle(number)
coherence_std_sides(number)
coherence_std_rest(number)

%%
%Calculate the average of the valley coherence in the sides and middle of
%the flake
% T = 100K, laser = 595, quarterwaveplate on flake 1

number = 6;     %in this file
place = 2;      %in file where came from

[a,b] = size(info100K_flake517.coherence);

punt{1}=[6,6]; punt{2}=[7,6]; punt{3}=[7,5]; punt{4}=[8,6]; punt{5}=[8,5];
punt{6}=[9,5]; punt{7}=[10,5]; punt{8}=[6,7]; punt{9}=[7,7]; punt{10}=[6,8];
punt{11}=[7,8]; punt{12}=[6,9]; punt{13}=[6,10]; punt{14}=[6,11]; punt{15}=[6,4]; 
punt{16}=[5,5]; punt{17}=[5,4]; punt{18}=[5,3]; punt{19}=[4,3]; punt{20}=[4,2];
punt{21}=[3,1];

took_middle_point = 0;

coherence_middle(number,:) = 0;
tellerM = 0;

coherence_sides(number,:) = 0;
tellerZ = 0;

coherence_rest(number,:) = 0;
tellerR = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info100K_flake517.Intens(jj,ii) > 1e5
            if info100K_flake517.Intens(jj,ii) > 4.1e5
                coherence_sides(number) = coherence_sides(number) + info100K_flake517.coherence(jj,ii);
                tellerZ = tellerZ + 1; 
            else
                for yy = 1:length(punt)
                    if [ii,jj]==punt{yy}
                        coherence_middle(number) = coherence_middle(number) + info100K_flake517.coherence(jj,ii);
                        tellerM = tellerM + 1;
                        took_middle_point = 1
                    end
                end
                if took_middle_point == 0
                    coherence_rest(number) = coherence_rest(number) + info100K_flake517.coherence(jj,ii);
                    tellerR = tellerR + 1;                     
                end
            end
        end
    end
end        

coherence_middle(number) = coherence_middle(number)/tellerM;
coherence_sides(number) = coherence_sides(number)/tellerZ;
coherence_rest(number) = coherence_rest(number)/tellerR;

coherence_middle(number)
coherence_sides(number)
coherence_rest(number)

%%
%Calculate the standard deviation of the valley coherence in the sides and middle of
%the flake
% T = 100K, laser = 595, quarterwaveplate on flake 1

coherence_std_middle(number,:) = 0;
coherence_std_sides(number,:) = 0;

tellerM = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info100K_flake517.Intens(jj,ii) > 1e5
            if info100K_flake517.Intens(jj,ii) > 4.8e5
                coherence_std_sides(number) = coherence_std_sides(number) + abs(info100K_flake517.coherence(jj,ii)-coherence_sides(number));
                tellerZ = tellerZ + 1;
            else
                for yy = 1:length(punt)
                    if [ii,jj]==punt{yy}               
                        coherence_std_middle(number) = coherence_std_middle(number) + abs(info100K_flake517.coherence(jj,ii)-coherence_middle(number));
                        tellerM = tellerM + 1;
                    end
                end
                if took_middle_point == 0
                    coherence_std_rest(number) = coherence_std_rest(number) + abs(info100K_flake517.coherence(jj,ii)-coherence_rest(number));
                    tellerR = tellerR + 1;
                end
            end
        end
    end
end        
coherence_std_middle(number) = coherence_std_middle(number)/tellerM;
coherence_std_sides(number) = coherence_std_sides(number)/tellerZ;
coherence_std_rest(number) = coherence_std_rest(number)/tellerR;

coherence_std_middle(number)
coherence_std_sides(number)
coherence_std_rest(number)


%%
%Calculate the average of the valley coherence in the sides and middle of
%the flake
% T = 200K, laser = 595, quarterwaveplate on flake 1

number = 7;     %in this file
place = 4;      %in file where came from

[a,b] = size(info200K_flake715.coherence);

punt{1}=[6,11]; punt{2}=[7,11]; punt{3}=[6,10]; punt{4}=[7,10]; punt{5}=[7,9];
punt{6}=[6,9]; punt{7}=[6,8]; punt{8}=[7,8]; punt{9}=[8,8]; punt{10}=[6,7];
punt{11}=[7,7]; punt{12}=[8,7]; punt{13}=[9,7]; punt{14}=[9,6]; punt{15}=[10,6]; 
punt{16}=[8,6]; punt{17}=[6,6]; punt{18}=[5,6]; punt{19}=[5,5]; punt{20}=[6,5];
punt{21}=[7,5]; punt{22}=[8,5]; punt{23}=[5,4]; punt{24}=[4,4]; punt{25}=[6,4];
punt{26}=[4,3]; punt{27}=[3,2];

took_middle_point = 0;

coherence_middle(number,:) = 0;
tellerM = 0;

coherence_sides(number,:) = 0;
tellerZ = 0;

coherence_rest(number,:) = 0;
tellerR = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info200K_flake715.Intens(jj,ii) > 1e5
            if info200K_flake715.Intens(jj,ii) > 2.6e5
                coherence_sides(number) = coherence_sides(number) + info200K_flake715.coherence(jj,ii);
                tellerZ = tellerZ + 1; 
            else
                for yy = 1:length(punt)
                    if [ii,jj]==punt{yy}
                        coherence_middle(number) = coherence_middle(number) + info200K_flake715.coherence(jj,ii);
                        tellerM = tellerM + 1;
                        took_middle_point = 1;
                    elseif [ii,jj]==[9,2] | [ii,jj]==[11,3] | [ii,jj]==[11,12] | [ii,jj]==[2,12]
                        took_middle_point = 1;                        
                    end     
                end                
                if took_middle_point == 0
                    coherence_rest(number) = coherence_rest(number) + info200K_flake715.coherence(jj,ii);
                    tellerR = tellerR + 1;                     
                end
            end
        end
    end
end        

coherence_middle(number) = coherence_middle(number)/tellerM;
coherence_sides(number) = coherence_sides(number)/tellerZ;
coherence_rest(number) = coherence_rest(number)/tellerR;

coherence_middle(number)
coherence_sides(number)
coherence_rest(number)

%%
%Calculate the standard deviation of the valley coherence in the sides and middle of
%the flake
% T = 200K, laser = 595, quarterwaveplate on flake 1

coherence_std_middle(number,:) = 0;
coherence_std_sides(number,:) = 0;

tellerM = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info200K_flake715.Intens(jj,ii) > 1e5
            if info200K_flake715.Intens(jj,ii) > 2.6e5
                coherence_std_sides(number) = coherence_std_sides(number) + abs(info200K_flake715.coherence(jj,ii)-coherence_sides(number));
                tellerZ = tellerZ + 1;
            else
                for yy = 1:length(punt)
                    if [ii,jj]==punt{yy}               
                        coherence_std_middle(number) = coherence_std_middle(number) + abs(info200K_flake715.coherence(jj,ii)-coherence_middle(number));
                        tellerM = tellerM + 1;
                    elseif [ii,jj]==[9,2] | [ii,jj]==[11,3] | [ii,jj]==[11,12] | [ii,jj]==[2,12]
                        took_middle_point = 1;                        
                    end
                end
                if took_middle_point == 0
                    coherence_std_rest(number) = coherence_std_rest(number) + abs(info200K_flake715.coherence(jj,ii)-coherence_rest(number));
                    tellerR = tellerR + 1;
                end
            end
        end
    end
end        
coherence_std_middle(number) = coherence_std_middle(number)/tellerM;
coherence_std_sides(number) = coherence_std_sides(number)/tellerZ;
coherence_std_rest(number) = coherence_std_rest(number)/tellerR;

coherence_std_middle(number)
coherence_std_sides(number)
coherence_std_rest(number)

%%
%Calculate the average of the valley coherence in the sides and middle of
%the flake
% T = 300K, laser = 595, quarterwaveplate on flake 1

number = 8;     %in this file
place = 7;      %in file where came from

[a,b] = size(info300K_flake1.coherence);

punt{1}=[6,9]; punt{2}=[6,8]; punt{3}=[6,7]; punt{4}=[6,6]; punt{5}=[7,6];
punt{6}=[6,5]; punt{7}=[7,5]; punt{8}=[8,5]; punt{9}=[7,4]; punt{10}=[8,4];
punt{11}=[9,4]; punt{12}=[10,4]; punt{13}=[5,4]; punt{14}=[5,3]; punt{15}=[6,3]; 
punt{16}=[7,3]; punt{17}=[4,3]; punt{18}=[4,2]; punt{19}=[3,2]; punt{20}=[11,4];

took_middle_point = 0;

coherence_middle(number,:) = 0;
tellerM = 0;

coherence_sides(number,:) = 0;
tellerZ = 0;

coherence_rest(number,:) = 0;
tellerR = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info300K_flake1.Intens(jj,ii) > 0
            if info300K_flake1.Intens(jj,ii) > 3.0e5
                coherence_sides(number) = coherence_sides(number) + info300K_flake1.coherence(jj,ii);
                tellerZ = tellerZ + 1; 
            else
                for yy = 1:length(punt)
                    if [ii,jj]==punt{yy}
                        coherence_middle(number) = coherence_middle(number) + info300K_flake1.coherence(jj,ii);
                        tellerM = tellerM + 1;
                        took_middle_point = 1;
                    elseif [ii,jj]==[4,6] 
                        took_middle_point = 1;                        
                    end     
                end                
                if took_middle_point == 0
                    coherence_rest(number) = coherence_rest(number) + info300K_flake1.coherence(jj,ii);
                    tellerR = tellerR + 1;                     
                end
            end
        end
    end
end        

coherence_middle(number) = coherence_middle(number)/tellerM;
coherence_sides(number) = coherence_sides(number)/tellerZ;
coherence_rest(number) = coherence_rest(number)/tellerR;

coherence_middle(number)
coherence_sides(number)
coherence_rest(number)

%%
%Calculate the standard deviation of the valley coherence in the sides and middle of
%the flake
% T = 300K, laser = 595, quarterwaveplate on flake 1

coherence_std_middle(number,:) = 0;
coherence_std_sides(number,:) = 0;

tellerM = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info300K_flake1.Intens(jj,ii) > 0
            if info300K_flake1.Intens(jj,ii) > 3.0e5
                coherence_std_sides(number) = coherence_std_sides(number) + abs(info300K_flake1.coherence(jj,ii)-coherence_sides(number));
                tellerZ = tellerZ + 1;
            else
                for yy = 1:length(punt)
                    if [ii,jj]==punt{yy}               
                        coherence_std_middle(number) = coherence_std_middle(number) + abs(info300K_flake1.coherence(jj,ii)-coherence_middle(number));
                        tellerM = tellerM + 1;
                    elseif [ii,jj]==[4,6] 
                        took_middle_point = 1;                        
                    end
                end
                if took_middle_point == 0
                    coherence_std_rest(number) = coherence_std_rest(number) + abs(info300K_flake1.coherence(jj,ii)-coherence_rest(number));
                    tellerR = tellerR + 1;
                end
            end
        end
    end
end        
coherence_std_middle(number) = coherence_std_middle(number)/tellerM;
coherence_std_sides(number) = coherence_std_sides(number)/tellerZ;
coherence_std_rest(number) = coherence_std_rest(number)/tellerR;

coherence_std_middle(number)
coherence_std_sides(number)
coherence_std_rest(number)

%%
%Figure 4f
%Fit the temperature dependence of the valley coherence and plot

xfit = temperatures';
yfit = coherence_middle(1:4);

fo=fitoptions('Method','NonlinearLeastSquares','StartPoint',[0.1,1,1e3]);
ft=fittype('a-b*exp(-c/(1.3806*x))','options',fo');

[curve gof2]=fit(xfit,yfit,ft)
waarden=coeffvalues(curve);

%-----------------------------------------------------------
yfit = coherence_sides(1:4);

fo=fitoptions('Method','NonlinearLeastSquares','StartPoint',[0.1,1,1e3]);
ft=fittype('a-b*exp(-c/(1.3806*x))','options',fo');

[curve2 gof2]=fit(xfit,yfit,ft)
waarden=coeffvalues(curve2);

%-----------------------------------------------------------
yfit = coherence_middle(5:8);

fo=fitoptions('Method','NonlinearLeastSquares','StartPoint',[0.1,1,1e3]);
ft=fittype('a-b*exp(-c/(1.3806*x))','options',fo');

[curve3 gof2]=fit(xfit,yfit,ft)
waarden=coeffvalues(curve3);

%-----------------------------------------------------------
yfit = coherence_sides(5:8);

fo=fitoptions('Method','NonlinearLeastSquares','StartPoint',[0.1,1,1e3]);
ft=fittype('a-b*exp(-c/(1.3806*x))','options',fo');

[curve4 gof2]=fit(xfit,yfit,ft)
waarden=coeffvalues(curve4);

%-----------------------------------------------------------

fg5 = figure(5); clf(fg5); set(gcf,'Color','w');

pl1=errorbar(temperatures,coherence_middle(1:4),coherence_std_middle(1:4),'o','MarkerFaceColor',[1 0.8 0],'color',[1 0.8 0]);
hold on
pl5 = plot(curve);
hold on
pl2=errorbar(temperatures,coherence_sides(1:4),coherence_std_sides(1:4),'p','MarkerFaceColor',[1 0.2 0],'color',[1 0.2 0]);
hold on
pl6 = plot(curve2);
hold on
pl3=errorbar(temperatures,coherence_middle(5:8),coherence_std_middle(5:8),'o','color',[1 0.8 0]);
hold on
pl7 = plot(curve3);
hold on
pl4=errorbar(temperatures,coherence_sides(5:8),coherence_std_sides(5:8),'p','color',[1 0.2 0]);
hold on
pl8 = plot(curve4);
hold off

xlabel('Temperature (K)')
ylabel('Valley coherence')

set(pl5,'color',[1 0.8 0]); set(pl6,'color',[1 0.2 0]);
set(pl7,'color',[1 0.8 0],'LineStyle','--'); set(pl8,'color',[1 0.2 0],'LineStyle','--');

leg=legend([pl3,pl4,pl1,pl2],{'fl.1','fl.2','fl.1','fl.2'});

print(fg5,strcat(figurepath,'figure4f.png'),'-dpng');

%%
%Figure S2a
%-calibrate the axes from V --> um
%-plot the map of S1
%4K, flake 1

axisX = linspace(stepX4K*info4K_flake175.sample_x(1)/10,stepX4K*info4K_flake175.sample_x(end)/10,length(info4K_flake175.sample_x));
axisY = linspace(stepY4K*info4K_flake175.sample_y(1)/10,stepY4K*info4K_flake175.sample_y(end)/10,length(info4K_flake175.sample_y));

fg6 = figure(6); clf(fg6); set(gcf,'Color','w');

imagesc(axisX,axisY,squeeze(abs(info4K_flake175.Stokes(1,:,:))))
colormap hot; caxis([0 0.6]); colorbar;

xlabel('X (um)');set(gca,'Xdir','reverse')
ylabel('Y (um)');set(gca,'Ydir','normal')
title('S1 of flake 1')

print(fg6,strcat(figurepath,'figureS2a'),'-dpng');

%%
%Figure S2b
%-plot the map of S2
%4K, flake 1

fg7 = figure(7); clf(fg7); set(gcf,'Color','w');

imagesc(axisX,axisY,squeeze(abs(info4K_flake175.Stokes(2,:,:))))
colormap hot; caxis([0 0.1]); cl=colorbar;

xlabel('X (um)');set(gca,'Xdir','reverse')
ylabel('Y (um)');set(gca,'Ydir','normal')
title('S2 of flake 1')

print(fg7,strcat(figurepath,'figureS2b'),'-dpng');

%%
%Figure S2c
%-plot the map of S3
%4K, flake 1

fg8 = figure(8); clf(fg8); set(gcf,'Color','w');

imagesc(axisX,axisY,squeeze(abs(info4K_flake175.Stokes(3,:,:))))
colormap hot; caxis([0 0.1]); cl=colorbar;

xlabel('X (um)');set(gca,'Xdir','reverse')
ylabel('Y (um)');set(gca,'Ydir','normal')
title('S3 of flake 1')

print(fg8,strcat(figurepath,'figureS2c'),'-dpng');

%%
%Figure S2e
%plot the three curves

colors{6} = 'b'; colors{4} = 'r'; colors{2} = 'g';

fg9 = figure(9); clf(fg9); set(gcf,'Color','w');

for ii = [2,4,6]
    pl=plot(info4K_flake1_linear.Angles{4},info4K_flake1_linear.Maxima595_4K_fl1(1,:,ii,5)/max(info4K_flake1_linear.Maxima595_4K_fl1(1,:,ii,5)),'color',colors{ii});
    hold on
end

xlim([0 90])
xticks([0 45 90])
xticklabels({'0','pi','2pi'})
xlabel('angle of analyzer')
ylabel('I_{normalized}')

print(fg9,strcat(figurepath,'figureS2e'),'-dpng');

%%
%Figure S2f
%-calibrate the axes V --> um
%-plot the map of linear polarization contrast
%4K, flake 1

axisX = linspace(stepX4K*info4K_flake1_linear.sample_x{4}(1)/10,stepX4K*info4K_flake1_linear.sample_x{4}(end)/10,length(info4K_flake1_linear.sample_x{4}));
axisY = linspace(stepY4K*info4K_flake1_linear.sample_y{4}(1)/10,stepY4K*info4K_flake1_linear.sample_y{4}(end)/10,length(info4K_flake1_linear.sample_y{4}));

colors{6} = 'b'; colors{4} = 'r'; colors{2} = 'g';

fg10 = figure(10); clf(fg10); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake1_linear.LinPol595_flake1_fit(:,:))
hold on
for ii = [2,4,6]
   pl=plot(axisX(5),axisY(ii),'p','color',colors{ii},'MarkerFaceColor',colors{ii},'MarkerSize',15);
   hold on
end

colormap bone; caxis([0 0.6]); colorbar;

xlabel('X (um)');set(gca,'Xdir','reverse')
ylabel('Y (um)');set(gca,'Ydir','normal')
title('Linear polarization of flake 1')

print(fg10,strcat(figurepath,'figureS2f'),'-dpng');


%%
%Figure S4a
%-calibrate the axes from V --> um
%-plot the map of the valley coherence
%100K, flake 2

axisX = linspace(stepX100K*info100K_flake285.sample_x(1)/10,stepX100K*info100K_flake285.sample_x(end)/10,length(info100K_flake285.sample_x));
axisY = linspace(stepY100K*info100K_flake285.sample_y(1)/10,stepY100K*info100K_flake285.sample_y(end)/10,length(info100K_flake285.sample_y));

fg11 = figure(11); clf(fg11); set(gcf,'Color','w');

imagesc(axisX,axisY,info100K_flake285.coherence)

colorbar; colormap hot; caxis([0 0.5])

xlabel('X (um)');set(gca,'Xdir','reverse')
ylabel('Y (um)');set(gca,'Ydir','normal')
title('Valley coherence fl.2, 100K')

print(fg11,strcat(figurepath,'figureS4a'),'-dpng');

%%
%Figure S4b
%-calibrate the axes from V --> um
%-plot the map of the valley coherence
%200K, flake 2

axisX = linspace(stepX200K*info200K_flake82.sample_x(1)/10,stepX200K*info200K_flake82.sample_x(end)/10,length(info200K_flake82.sample_x));
axisY = linspace(stepY200K*info200K_flake82.sample_y(1)/10,stepY200K*info200K_flake82.sample_y(end)/10,length(info200K_flake82.sample_y));

fg12 = figure(12); clf(fg12); set(gcf,'Color','w');

imagesc(axisX,axisY,info200K_flake82.coherence)

caxis([0 0.6]); colormap hot; colorbar;

xlabel('X (um)');set(gca,'Xdir','reverse')
ylabel('Y (um)');set(gca,'Ydir','normal')
title('Valley coherence fl.2, 200K')

print(fg12,strcat(figurepath,'figureS4b'),'-dpng');

%%
%Figure S4c
%-calibrate the axes from V --> um
%-plot the map of the valley coherence
%300K, flake 2

axisX = linspace(stepX300K*info300K_flake285.sample_x(1)/10,stepX300K*info300K_flake285.sample_x(end)/10,length(info300K_flake285.sample_x));
axisY = linspace(stepY300K*info300K_flake285.sample_y(1)/10,stepY300K*info300K_flake285.sample_y(end)/10,length(info300K_flake285.sample_y));

fg13 = figure(13); clf(fg13); set(gcf,'Color','w');

imagesc(axisX,axisY,info300K_flake285.coherence)

caxis([0 0.6]); colormap hot; colorbar;

xlabel('X (um)');set(gca,'Xdir','reverse')
ylabel('Y (um)');set(gca,'Ydir','normal')
title('Valley coherence fl.2, 300K')

print(fg13,strcat(figurepath,'figureS4c'),'-dpng');



