%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%This is the software to make the images for article

%Requirements:
%   -change path into the path to your folder
%   -make sure the program vivid is in this folder (for the colormap)
%   -make sure the data are in the data folder
%   -make sure there is an image folder to save the images to
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
clc;
clear;
close all;

path = 'N:\tnw\NS\kuiperslab\Irina\writing_articles\article_polarization\open_data\';

datapath = strcat(path,'data\');
figurepath=strcat(path,'images\');

%%
%This software does the following:
%   import information of fitted spectra and valley polarization
%   calculate average and standard deviation of valley polarization maps at
%   different temperatures
%   plot subfigures of figure 3 in main text
%   plot subfigures of figure S3 in the supplementary

%%
%Import all the fitted spectra and the results of the fit

temperature = [4 100 200 300];

stepX300K = 12.0; stepY300K = 8.0; %calibration piezo V --> um
stepX200K = 7.5; stepY200K = 4.0; %calibration piezo V --> um
stepX100K = 6.0; stepY100K = 3.0;%calibration piezo V --> um
stepX4K = 2.5; stepY4K = 1.5;  %calibration piezo V --> um

info300K_flake1valley = load(strcat(datapath,'Info_2802_flake1_fits','.mat'));
info200K_flake1valley = load(strcat(datapath,'Info_1703_flake1_fits','.mat'));
info100K_flake1valley = load(strcat(datapath,'Info_1203_flake1_fits','.mat'));
info4K_flake1valley = load(strcat(datapath,'Info_3006_flake1_fits','.mat'));

info300K_flake285 = load(strcat(datapath,'Info_0907_flake8_fits','.mat'));
info200K_flake82 = load(strcat(datapath,'Info_0807_flake8_fits','.mat'));
info100K_flake285 = load(strcat(datapath,'Info_0307_flake8_fits','.mat'));
info4K_flake582 = load(strcat(datapath,'Info_0207_flake8_fits','.mat'));

%%
%This is needed to make the blue-red colormap

level = 52; n = ceil(level/2);
cmap1 = [linspace(1, 1, n); linspace(0, 1, n); linspace(0, 1, n)]';
cmap2 = [linspace(1, 0, n); linspace(1, 0, n); linspace(1, 1, n)]';
cmap = [cmap1; cmap2(2:end, :)];
cmap=flip(cmap);

%%
%Figure 3c
%Plot the four spectra of sigma+ and sigma- polarization

pos1 = [13,12]; pos2 = [6,3];

fg1 = figure(1); clf(fg1); set(gcf,'Color','w');

plot(info4K_flake1valley.wavelength{1},info4K_flake1valley.Spectrum{1}(:,2,pos1(1),pos1(2))-info4K_flake1valley.background_broad(:,3),'r');
hold on
plot(info4K_flake1valley.wavelength{1},info4K_flake1valley.Spectrum{1}(:,1,pos1(1),pos1(2))-info4K_flake1valley.background_broad(:,3),'color',[1 0.5 0.5]);
hold on
plot(info4K_flake1valley.wavelength{1},info4K_flake1valley.Spectrum{1}(:,2,pos2(1),pos2(2))-info4K_flake1valley.background_broad(:,3),'b');
hold on
plot(info4K_flake1valley.wavelength{1},info4K_flake1valley.Spectrum{1}(:,1,pos2(1),pos2(2))-info4K_flake1valley.background_broad(:,3),'color',[0.5 0.5 1]);
hold off

xlim([580 700])

xlabel('wavelength (nm)');
ylabel('I (counts/100ms)');
legend('\sigma -','\sigma +','\sigma +','\sigma -')

print(fg1,strcat(figurepath,'figure3c.png'),'-dpng');

%%
%Figure 3d
%-Determine the axes using the calibration of V --> um
%-Plot the map of valley polarization of fl.1
%4K, flake 1

pos1 = [13,12]; pos2 = [6,3];

axisX = linspace(stepX4K*info4K_flake1valley.sample_x{1}(2)/10,stepX4K*info4K_flake1valley.sample_x{1}(end)/10,length(info4K_flake1valley.sample_x{1})-1);
axisY = linspace(stepY4K*info4K_flake1valley.sample_y{1}(1)/10,stepY4K*info4K_flake1valley.sample_y{1}(end)/10,length(info4K_flake1valley.sample_y{1}));

fg2 = figure(2); clf(fg2); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake1valley.ValleyPol595_flake1_fit(:,2:end))
hold on
plot(axisX(pos1(2)),axisY(pos1(1)),'ok','markersize',15);
hold on
plot(axisX(pos2(2)),axisY(pos2(1)),'pk','markersize',15);
hold off

colorbar; colormap(vivid(cmap, [.5 .5])); caxis([0.1 0.7])

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')

print(fg2,strcat(figurepath,'figure3d.png'),'-dpng');

%%
%Figure 3e
%-Determine the axes using the calibration of V --> um
%-Plot the map of valley polarization 
%4K, flake 2

axisX = linspace(stepX4K*info4K_flake582.sample_x{2}(1)/10,stepX4K*info4K_flake582.sample_x{2}(end)/10,length(info4K_flake582.sample_x{2}));
axisY = linspace(stepY4K*info4K_flake582.sample_y{2}(1)/10,stepY4K*info4K_flake582.sample_y{2}(end)/10,length(info4K_flake582.sample_y{2}));

fg3 = figure(3); clf(fg3); set(gcf,'Color','w');

imagesc(axisX,axisY,info4K_flake582.ValleyPol595_flake8_fit(:,:))

colorbar; colormap(vivid(cmap, [.5 .5])); caxis([0.1 0.7])

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')

print(fg3,strcat(figurepath,'figure3e.png'),'-dpng');

%%
Valley_middle = zeros(10);
Valley_sides = zeros(10);
Valley_rest = zeros(10);

Valley_std_middle = zeros(10);
Valley_std_sides = zeros(10);
Valley_std_rest = zeros(10);

%%
%Calculate the average of the valley polarization in the sides and middle of
%the flake
% T = 4K, laser = 595, valley polarization on flake 1

number = 1;     %in this file

[a,b] = size(info4K_flake1valley.ValleyPol595_flake1_fit);

Valley_middle(number) = 0;
tellerM = 0;

Valley_sides(number) = 0;
tellerZ = 0;

Valley_rest(number) = 0;
tellerR = 0;

teller = 1;

for ii = [3:4]
    punt{teller}=[8,ii];
    teller=teller+1;
end

for ii = [2:7]
    punt{teller}=[9,ii];
    teller=teller+1;
end

for ii = [5:10]
    punt{teller}=[10,ii];
    teller=teller+1;
end

for ii = [5,6,11:18]
    punt{teller}=[11,ii];
    teller=teller+1;
end

for ii = [6,7,13:18]
    punt{teller}=[12,ii];
    teller=teller+1;
end

for ii = [6,7,12:14]
    punt{teller}=[13,ii];
    teller=teller+1;    
end

for ii = [7,8,11:13]
    punt{teller}=[14,ii];
    teller=teller+1;    
end

for ii = [8:12]
    punt{teller}=[15,ii];
    teller=teller+1;    
end

for ii = 16
    punt{teller}=[ii,8];
    teller=teller+1;
end
punt{teller}=[16,9];

took_middle_point = 0;
for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info4K_flake1valley.ValleyPol595_flake1_fit(jj,ii) > 0 & info4K_flake1valley.Maxima595_4K_flake1(1,2,jj,ii) > 1e4
            for yy = 1:length(punt)
                if [ii,jj]==punt{yy}
                    Valley_middle(number) = Valley_middle(number) + info4K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerM = tellerM + 1;
                    took_middle_point = 1;
                end
            end            
            if took_middle_point == 0
                if info4K_flake1valley.Maxima595_4K_flake1(1,2,jj,ii) > 2.0e4
                    Valley_sides(number) = Valley_sides(number) + info4K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerZ = tellerZ + 1;            
                else
                    Valley_rest(number) = Valley_rest(number) + info4K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerR = tellerR + 1;                    
                end
            end
        end
    end
end        

Valley_middle(number) = Valley_middle(number)/tellerM;
Valley_middle(number)

Valley_sides(number) = Valley_sides(number)/tellerZ;
Valley_sides(number)

Valley_rest(number) = Valley_rest(number)/tellerR;
Valley_rest(number)

%%
%Calculate the standard deviation of the valley polarization in the sides and middle of
%the flake
% T = 4K, laser = 595, valley polarization on flake 1
Valley_std_middle(number) = 0;
tellerM = 0;

Valley_std_sides(number) = 0;
tellerZ = 0;

Valley_std_rest(number) = 0;
tellerR = 0;

tellerM = 0;

took_middle_point = 0;
for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        info4K_flake1valley.ValleyPol595_flake1_fit(jj,ii) > 0 & info4K_flake1valley.Maxima595_4K_flake1(1,2,jj,ii) > 1e4
        for yy = 1:length(punt)
            if [ii,jj]==punt{yy}
                Valley_std_middle(number) = Valley_std_middle(number) + abs(info4K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_middle(number));
                tellerM = tellerM + 1; 
                took_middle_point == 1;
            end
        end   
        if took_middle_point == 0
            if info4K_flake1valley.Maxima595_4K_flake1(1,2,jj,ii) > 2e4      
                Valley_std_sides(number) = Valley_std_sides(number) + abs(info4K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_sides(number));
                tellerZ = tellerZ + 1;            
            else
                Valley_std_rest(number) = Valley_std_rest(number) + abs(info4K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_rest(number));
                tellerR = tellerR + 1;
            end
        end
    end
end     

Valley_std_sides(number) = Valley_std_sides(number)/tellerZ;
Valley_std_middle(number) = Valley_std_middle(number)/tellerM;
Valley_std_rest(number) = Valley_std_rest(number)/tellerR;

%%
%Calculate the average of the valley polarization in the sides and middle of
%the flake
% T = 100K, laser = 595, valley polarization on flake 1

number = 2;     %in this file
place = 2;

[a,b] = size(info100K_flake1valley.ValleyPol595_flake1_fit);

Valley_middle(number) = 0;
tellerM = 0;

Valley_sides(number) = 0;
tellerZ = 0;

Valley_rest(number) = 0;
tellerR = 0;

teller = 1;
for ii = [3:5]
    punt{teller}=[4,ii];
    teller=teller+1;
end

for ii = [4:8]
    punt{teller}=[5,ii];
    teller=teller+1;
end

for ii = [5:6,9:16]
    punt{teller}=[6,ii];
    teller=teller+1;
end

for ii = [6:11]
    punt{teller}=[7,ii];
    teller=teller+1;
end

for ii = [7:9]
    punt{teller}=[8,ii];
    teller=teller+1;
end

for ii = 9:11
    punt{teller}=[ii,7];
    teller=teller+1;
end
punt{teller}=[9,8];

took_middle_point = 0;
for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info100K_flake1valley.ValleyPol595_flake1_fit(jj,ii) > 0 & info100K_flake1valley.Maxima595_100K_flake1(1,2,jj,ii) > 8e3
            for yy = 1:length(punt)
                if [ii,jj]==punt{yy}
                    Valley_middle(number) = Valley_middle(number) + info100K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerM = tellerM+1;
                    took_middle_point = 1;
                end
            end            
            if took_middle_point == 0
                if info100K_flake1valley.Maxima595_100K_flake1(1,2,jj,ii) > 2.2e4
                    Valley_sides(number) = Valley_sides(number) + info100K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerZ = tellerZ + 1;            
                else            
                    Valley_rest(number) = Valley_rest(number) + info100K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerR = tellerR + 1;                    
                end
            end
        end
    end
end        

Valley_middle(number) = Valley_middle(number)/tellerM;
Valley_middle(number)

Valley_sides(number) = Valley_sides(number)/tellerZ;
Valley_sides(number)

Valley_rest(number) = Valley_rest(number)/tellerR;
Valley_rest(number)


%%
%Calculate the standard deviation of the valley polarization in the sides and middle of
%the flake
% T = 100K, laser = 595, valley polarization on flake 1

Valley_std_middle(number) = 0;
tellerM = 0;

Valley_std_sides(number) = 0;
tellerZ = 0;

Valley_std_rest(number) = 0;
tellerR = 0;

tellerM = 0;

took_middle_point = 0;
for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info100K_flake1valley.ValleyPol595_flake1_fit(jj,ii) > 0 & info100K_flake1valley.Maxima595_100K_flake1(1,2,jj,ii) > 8e3
            for yy = 1:length(punt)
                if [ii,jj]==punt{yy}
                    Valley_std_middle(number) = Valley_std_middle(number) + abs(info100K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_middle(number));
                    tellerM = tellerM+1;
                end
            end            
            if info100K_flake1valley.Maxima595_100K_flake1(1,2,jj,ii) > 2.2e4      
                Valley_std_sides(number) = Valley_std_sides(number) + abs(info100K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_sides(number));
                tellerZ = tellerZ + 1;            
            else 
                if took_middle_point == 0
                    Valley_std_rest(number) = Valley_std_rest(number) + abs(info100K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_rest(number));
                    tellerR = tellerR + 1;
                end
            end
        end
    end
end     

Valley_std_sides(number) = Valley_std_sides(number)/tellerZ;
Valley_std_middle(number) = Valley_std_middle(number)/tellerM;
Valley_std_rest(number) = Valley_std_rest(number)/tellerR;

%%
%Calculate the average of the valley polarization in the sides and middle of
%the flake
% T = 200K, laser = 595, valley polarization on flake 1

number = 3;     %in this file
place = 4;

[a,b] = size(info200K_flake1valley.ValleyPol595_flake1_fit);

Valley_middle(number) = 0;
tellerM = 0;

Valley_sides(number) = 0;
tellerZ = 0;

Valley_rest(number) = 0;
tellerR = 0;

teller = 1;
for ii = [1:2]
    punt{teller}=[4,ii];
    teller=teller+1;
end

for ii = [3:5]
    punt{teller}=[5,ii];
    teller=teller+1;
end

for ii = [4:8]
    punt{teller}=[6,ii];
    teller=teller+1;
end

for ii = [5:6,8:13]
    punt{teller}=[7,ii];
    teller=teller+1;
end

for ii = [6:9]
    punt{teller}=[8,ii];
    teller=teller+1;
end

for ii = 9:10
    punt{teller}=[ii,7];
    teller=teller+1;
end

took_middle_point = 0;
for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info200K_flake1valley.ValleyPol595_flake1_fit(jj,ii) > 0
            for yy = 1:length(punt)
                if [ii,jj]==punt{yy}
                    Valley_middle(number) = Valley_middle(number) + info200K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerM = tellerM + 1;
                    took_middle_point = 1;
                end
            end
            if took_middle_point == 0
                if info200K_flake1valley.Maxima595_200K_flake1(1,2,jj,ii) > 1.6e4
                    Valley_sides(number) = Valley_sides(number) + info200K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerZ = tellerZ + 1;            
                else
                    Valley_rest(number) = Valley_rest(number) + info200K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerR = tellerR + 1;                    
                end
            end
        end
    end
end        

Valley_middle(number) = Valley_middle(number)/tellerM;
Valley_middle(number)

Valley_sides(number) = Valley_sides(number)/tellerZ;
Valley_sides(number)

Valley_rest(number) = Valley_rest(number)/tellerR;
Valley_rest(number)


%%
%Calculate the standard deviation of the valley polarization in the sides and middle of
%the flake
% T = 200K, laser = 595, valley polarization on flake 1

Valley_std_middle(number) = 0;
tellerM = 0;

Valley_std_sides(number) = 0;
tellerZ = 0;

Valley_std_rest(number) = 0;
tellerR = 0;

tellerM = 0;

took_middle_point = 0;
for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info200K_flake1valley.ValleyPol595_flake1_fit(jj,ii) > 0
            for yy = 1:length(punt)
                if [ii,jj]==punt{yy}
                    Valley_std_middle(number) = Valley_std_middle(number) + abs(info200K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_middle(number));
                    tellerM = tellerM + 1;
                    took_middle_point = 1;
                end
            end
            if took_middle_point == 0
                if info200K_flake1valley.Maxima595_200K_flake1(1,2,jj,ii) > 1.6e4      
                    Valley_std_sides(number) = Valley_std_sides(number) + abs(info200K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_sides(number));
                    tellerZ = tellerZ + 1;            
                else
                    Valley_std_rest(number) = Valley_std_rest(number) + abs(info200K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_rest(number));
                    tellerR = tellerR + 1;
                end
            end
        end
    end
end     

Valley_std_sides(number) = Valley_std_sides(number)/tellerZ;
Valley_std_middle(number) = Valley_std_middle(number)/tellerM;
Valley_std_rest(number) = Valley_std_rest(number)/tellerR;

%%
%Calculate the average of the valley polarization in the sides and middle of
%the flake
% T = 300K, laser = 595, valley polarization on flake 1

number = 4;     %in this file
place = 4;

[a,b] = size(info300K_flake1valley.ValleyPol595_flake1_fit);

Valley_middle(number) = 0;
tellerM = 0;

Valley_sides(number) = 0;
tellerZ = 0;

Valley_rest(number) = 0;
tellerR = 0;

teller = 1;
for ii = [8:10]
    punt{teller}=[8,ii];
    teller=teller+1;
end

for ii = [9:12]
    punt{teller}=[9,ii];
    teller=teller+1;
end

for ii = [10:14]
    punt{teller}=[10,ii];
    teller=teller+1;
end

for ii = [12:13,16:26]
    punt{teller}=[11,ii];
    teller=teller+1;
end

for ii = [13:14,17:26]
    punt{teller}=[12,ii];
    teller=teller+1;
end

for ii = 13:17
    punt{teller}=[13,ii];
    teller=teller+1;
end

for ii = 14:16
    punt{teller}=[14,ii];
    teller=teller+1;
end

for ii = 15:17
    punt{teller}=[ii,15];
    teller=teller+1;
end

took_middle_point = 0;
for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info300K_flake1valley.ValleyPol595_flake1_fit(jj,ii) > 0
            for yy = 1:length(punt)
                if [ii,jj]==punt{yy}
                    Valley_middle(number) = Valley_middle(number) + info300K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerM = tellerM + 1;
                    took_middle_point = 1;
                end
            end
            if ii==11 & jj==15
                took_middle_point = 1;
            elseif ii==12 & jj==16
                took_middle_point = 1;
            end  
            if took_middle_point == 0
                if info300K_flake1valley.Maxima595_300K_flake1(1,2,jj,ii) > 1e4
                    Valley_sides(number) = Valley_sides(number) + info300K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerZ = tellerZ + 1;            
                else
                    Valley_rest(number) = Valley_rest(number) + info300K_flake1valley.ValleyPol595_flake1_fit(jj,ii);
                    tellerR = tellerR + 1;                    
                end
            end
        end
    end
end        

Valley_middle(number) = Valley_middle(number)/tellerM;
Valley_middle(number)

Valley_sides(number) = Valley_sides(number)/tellerZ;
Valley_sides(number)

Valley_rest(number) = Valley_rest(number)/tellerR;
Valley_rest(number)


%%
%Calculate the standard deviation of the valley polarization in the sides and middle of
%the flake
% T = 300K, laser = 595, valley polarization on flake 1

Valley_std_middle(number) = 0;
tellerM = 0;

Valley_std_sides(number) = 0;
tellerZ = 0;

Valley_std_rest(number) = 0;
tellerR = 0;

tellerM = 0;

took_middle_point = 0;
for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info300K_flake1valley.ValleyPol595_flake1_fit(jj,ii) > 0
            for yy = 1:length(punt)
                if [ii,jj]==punt{yy}
                    Valley_std_middle(number) = Valley_std_middle(number) + abs(info300K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_middle(number));
                    tellerM = tellerM + 1;
                    took_middle_point = 1;
                end
            end  
            if ii==12 & jj==15
                took_middle_point = 1;
            elseif ii==12 & jj==16
                took_middle_point = 1;
            end              
            if took_middle_point == 0
                if info300K_flake1valley.Maxima595_300K_flake1(1,2,jj,ii) > 1e4     
                    Valley_std_sides(number) = Valley_std_sides(number) + abs(info300K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_sides(number));
                    tellerZ = tellerZ + 1;            
                else
                    Valley_std_rest(number) = Valley_std_rest(number) + abs(info300K_flake1valley.ValleyPol595_flake1_fit(jj,ii)-Valley_rest(number));
                    tellerR = tellerR + 1;
                end
            end
        end
    end
end     

Valley_std_sides(number) = Valley_std_sides(number)/tellerZ;
Valley_std_middle(number) = Valley_std_middle(number)/tellerM;
Valley_std_rest(number) = Valley_std_rest(number)/tellerR;


%%
%Calculate the average of the valley polarization in the sides and middle of
%the flake
% T = 4K, laser = 595, valley polarization on flake 2

number = 5;     %in this file
place = 2;

[a,b] = size(info4K_flake582.ValleyPol595_flake8_fit);

Valley_middle(number) = 0;
tellerM = 0;

Valley_sides(number) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        if info4K_flake582.Maxima595_4K_flake8(1,2,jj,ii) > 6e3
            if info4K_flake582.Maxima595_4K_flake8(1,2,jj,ii) > 1.4e4
                Valley_sides(number) = Valley_sides(number) + info4K_flake582.ValleyPol595_flake8_fit(jj,ii);
                tellerZ = tellerZ + 1;            
            else
                Valley_middle(number) = Valley_middle(number) + info4K_flake582.ValleyPol595_flake8_fit(jj,ii);
                tellerM = tellerM + 1;
            end
        elseif info4K_flake582.Maxima595_4K_flake8(1,2,jj,ii) < 2e3
            if ii > 10
                info4K_flake582.ValleyPol595_flake8_fit(jj,ii) = 0;
            end
        end
    end
end        

Valley_middle(number) = Valley_middle(number)/tellerM;
Valley_middle(number)

Valley_sides(number) = Valley_sides(number)/tellerZ;
Valley_sides(number)


%%
%Calculate the standard deviation of the valley polarization in the sides and middle of
%the flake
% T = 4K, laser = 595, valley polarization on flake 2

Valley_std_middle(number) = 0;
tellerM = 0;

Valley_std_sides(number) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info4K_flake582.Maxima595_4K_flake8(1,2,jj,ii) > 6e3
            if info4K_flake582.Maxima595_4K_flake8(1,2,jj,ii) > 1.4e4      
                Valley_std_sides(number) = Valley_std_sides(number) + abs(info4K_flake582.ValleyPol595_flake8_fit(jj,ii)-Valley_sides(number));
                tellerZ = tellerZ + 1;            
            else
                Valley_std_middle(number) = Valley_std_middle(number) + abs(info4K_flake582.ValleyPol595_flake8_fit(jj,ii)-Valley_middle(number));
                tellerM = tellerM + 1; 
            end
        end
    end
end     

Valley_std_sides(number) = Valley_std_sides(number)/tellerZ;
Valley_std_middle(number) = Valley_std_middle(number)/tellerM;

%%
%Calculate the average of the valley polarization in the sides and middle of
%the flake
% T = 100K, laser = 595, valley polarization on flake 2

number = 6;     %in this file
place = 4;

[a,b] = size(info100K_flake285.ValleyPol595_flake8_fit);

Valley_middle(number) = 0;
tellerM = 0;

Valley_sides(number) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        if info100K_flake285.Maxima595_100K_flake8(1,2,jj,ii) > 3e3
            if info100K_flake285.Maxima595_100K_flake8(1,2,jj,ii) > 1.1e4
                Valley_sides(number) = Valley_sides(number) + info100K_flake285.ValleyPol595_flake8_fit(jj,ii);
                tellerZ = tellerZ + 1;            
            else
                Valley_middle(number) = Valley_middle(number) + info100K_flake285.ValleyPol595_flake8_fit(jj,ii);
                tellerM = tellerM + 1;
            end
        end
    end
end        

Valley_middle(number) = Valley_middle(number)/tellerM;
Valley_middle(number)

Valley_sides(number) = Valley_sides(number)/tellerZ;
Valley_sides(number)


%%
%Calculate the standard deviation of the valley polarization in the sides and middle of
%the flake
% T = 100K, laser = 595, valley polarization on flake 2

Valley_std_middle(number) = 0;
tellerM = 0;

Valley_std_sides(number) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info100K_flake285.Maxima595_100K_flake8(1,2,jj,ii) > 3e3
            if info100K_flake285.Maxima595_100K_flake8(1,2,jj,ii) > 1.1e4  
                Valley_std_sides(number) = Valley_std_sides(number) + abs(info100K_flake285.ValleyPol595_flake8_fit(jj,ii)-Valley_sides(number));
                tellerZ = tellerZ + 1;            
            else
                Valley_std_middle(number) = Valley_std_middle(number) + abs(info100K_flake285.ValleyPol595_flake8_fit(jj,ii)-Valley_middle(number));
                tellerM = tellerM + 1; 
            end
        end
    end
end     

Valley_std_sides(number) = Valley_std_sides(number)/tellerZ;
Valley_std_middle(number) = Valley_std_middle(number)/tellerM;

%%
%Calculate the average of the valley polarization in the sides and middle of
%the flake
% T = 200K, laser = 595, valley polarization on flake 2

number = 7;     %in this file
place = 2;

[a,b] = size(info200K_flake82.ValleyPol595_flake8_fit);

Valley_middle(number) = 0;
tellerM = 0;

Valley_sides(number) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        if info200K_flake82.Maxima595_200K_flake8(1,2,jj,ii) > 1.5e3
            if info200K_flake82.Maxima595_200K_flake8(1,2,jj,ii) > 5e3
                Valley_sides(number) = Valley_sides(number) + info200K_flake82.ValleyPol595_flake8_fit(jj,ii);
                tellerZ = tellerZ + 1;            
            else
                Valley_middle(number) = Valley_middle(number) + info200K_flake82.ValleyPol595_flake8_fit(jj,ii);
                tellerM = tellerM + 1;
            end
        end
    end
end        

Valley_middle(number) = Valley_middle(number)/tellerM;
Valley_middle(number)

Valley_sides(number) = Valley_sides(number)/tellerZ;
Valley_sides(number)


%%
%Calculate the standard deviation of the valley polarization in the sides and middle of
%the flake
% T = 200K, laser = 595, valley polarization on flake 2

Valley_std_middle(number) = 0;
tellerM = 0;

Valley_std_sides(number) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info200K_flake82.Maxima595_200K_flake8(1,2,jj,ii) > 1.5e3
            if info200K_flake82.Maxima595_200K_flake8(1,2,jj,ii) > 5e3
                Valley_std_sides(number) = Valley_std_sides(number) + abs(info200K_flake82.ValleyPol595_flake8_fit(jj,ii)-Valley_sides(number));
                tellerZ = tellerZ + 1;            
            else
                Valley_std_middle(number) = Valley_std_middle(number) + abs(info200K_flake82.ValleyPol595_flake8_fit(jj,ii)-Valley_middle(number));
                tellerM = tellerM + 1; 
            end
        end
    end
end     

Valley_std_sides(number) = Valley_std_sides(number)/tellerZ;
Valley_std_middle(number) = Valley_std_middle(number)/tellerM;

%%
%Calculate the average of the valley polarization in the sides and middle of
%the flake
% T = 300K, laser = 595, valley polarization on flake 2

number = 8;     %in this file
place = 3;

[a,b] = size(info300K_flake285.ValleyPol595_flake8_fit);

Valley_middle(number) = 0;
tellerM = 0;

Valley_sides(number) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        if info300K_flake285.Maxima595_300K(1,2,jj,ii) > 1.4e3
            if info300K_flake285.Maxima595_300K(1,2,jj,ii) > 3.8e3
                Valley_sides(number) = Valley_sides(number) + info300K_flake285.ValleyPol595_flake8_fit(jj,ii);
                tellerZ = tellerZ + 1;            
            else
                Valley_middle(number) = Valley_middle(number) + info300K_flake285.ValleyPol595_flake8_fit(jj,ii);
                tellerM = tellerM + 1;
            end
        end
    end
end        

Valley_middle(number) = Valley_middle(number)/tellerM;
Valley_middle(number)

Valley_sides(number) = Valley_sides(number)/tellerZ;
Valley_sides(number)


%%
%Calculate the standard deviation of the valley polarization in the sides and middle of
%the flake
% T = 300K, laser = 595, valley polarization on flake 2

Valley_std_middle(number) = 0;
tellerM = 0;

Valley_std_sides(number) = 0;
tellerZ = 0;

for ii = 1:b
    for jj = 1:a
        took_middle_point = 0;
        if info300K_flake285.Maxima595_300K(1,2,jj,ii) > 1.4e3
            if info300K_flake285.Maxima595_300K(1,2,jj,ii) > 3.8e3
                Valley_std_sides(number) = Valley_std_sides(number) + abs(info300K_flake285.ValleyPol595_flake8_fit(jj,ii)-Valley_sides(number));
                tellerZ = tellerZ + 1;            
            else
                Valley_std_middle(number) = Valley_std_middle(number) + abs(info300K_flake285.ValleyPol595_flake8_fit(jj,ii)-Valley_middle(number));
                tellerM = tellerM + 1; 
            end
        end
    end
end     

Valley_std_sides(number) = Valley_std_sides(number)/tellerZ;
Valley_std_middle(number) = Valley_std_middle(number)/tellerM;

%%
%Figure 3f
%Fit the temperature dependence curves
%Plot the curves
%Plot the fits

xfit = temperature';
yfit = Valley_middle(1:4,1);

fo=fitoptions('Method','NonlinearLeastSquares','StartPoint',[0.1,1,1e3]);
ft=fittype('a-b*exp(-c/(1.3806*x))','options',fo');

[curve gof2]=fit(xfit,yfit,ft)
waarden=coeffvalues(curve);

%-------------------------------------

yfit = Valley_sides(1:4,1);

fo=fitoptions('Method','NonlinearLeastSquares','StartPoint',[0.1,1,1e3]);
ft=fittype('a-b*exp(-c/(1.3806*x))','options',fo');

[curve2 gof2]=fit(xfit,yfit,ft)
waarden=coeffvalues(curve2);

%-------------------------------------

yfit = Valley_middle(5:8,1);

fo=fitoptions('Method','NonlinearLeastSquares','StartPoint',[0.1,1,1e3]);
ft=fittype('a-b*exp(-c/(1.3806*x))','options',fo');

[curve3 gof2]=fit(xfit,yfit,ft)
waarden=coeffvalues(curve3);

%-------------------------------------

yfit = Valley_sides(5:8,1);

fo=fitoptions('Method','NonlinearLeastSquares','StartPoint',[0.4,0.5,3e3]);
ft=fittype('a-b*exp(-c/(1.3806*x))','options',fo');

[curve4 gof2]=fit(xfit,yfit,ft)
waarden=coeffvalues(curve4);

%-------------------------------------

fg4 = figure(4); clf(fg4); set(gcf,'Color','w');

pl1=errorbar(temperature,Valley_middle(1:4,1),Valley_std_middle(1:4,1),'or');
hold on
pl5 = plot(curve)
hold on
pl2=errorbar(temperature,Valley_sides(1:4,1),Valley_std_sides(1:4,1),'pb');
hold on
pl6 = plot(curve2)
hold on
pl3=errorbar(temperature,Valley_middle(5:8,1),Valley_std_middle(5:8,1),'or','MarkerFaceColor','r');
hold on
pl7 = plot(curve3)
hold on
pl4=errorbar(temperature,Valley_sides(5:8,1),Valley_std_sides(5:8,1),'pb','MarkerFaceColor','b')
hold on
pl8 = plot(curve4)
hold off

xlabel('Temperature (K)')
ylabel('Valley polarization')

set(pl5,'color','r','LineStyle','--'); set(pl6,'color','b','LineStyle','--');
set(pl7,'color','r'); set(pl8,'color','b');

print(fg4,strcat(figurepath,'figure3f.png'),'-dpng');

%%
%Figure S3a
%calibrate the axes from V --> um
%plot the map of the valley coherence
%100K, flake 1

axisX = linspace(stepX100K*info100K_flake1valley.sample_x{2}(1)/10,stepX100K*info100K_flake1valley.sample_x{2}(end)/10,length(info100K_flake1valley.sample_x{2}));
axisY = linspace(stepY100K*info100K_flake1valley.sample_y{2}(1)/10,stepY100K*info100K_flake1valley.sample_y{2}(end)/10,length(info100K_flake1valley.sample_y{2}));

fg5 = figure(5); clf(fg5); set(gcf,'Color','w');

imagesc(axisX,axisY,info100K_flake1valley.ValleyPol595_flake1_fit)

colorbar; colormap(vivid(cmap, [.5 .5])); caxis([0.1 0.65])

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('100K, flake 1')

print(fg5,strcat(figurepath,'figureS3a.png'),'-dpng');


%%
%Figure S3b
%calibrate the axes from V --> um
%plot the map of the valley coherence
%200K, flake 1

axisX = linspace(stepX200K*info200K_flake1valley.sample_x{4}(2)/10,stepX200K*info200K_flake1valley.sample_x{4}(end-1)/10,length(info200K_flake1valley.sample_x{4})-2);
axisY = linspace(stepY200K*info200K_flake1valley.sample_y{4}(1)/10,stepY200K*info200K_flake1valley.sample_y{4}(end)/10,length(info200K_flake1valley.sample_y{4}));

fg6 = figure(6); clf(fg6); set(gcf,'Color','w');

imagesc(axisX,axisY,info200K_flake1valley.ValleyPol595_flake1_fit(:,2:end-1))

colorbar; colormap(vivid(cmap, [.5 .5])); caxis([0.1 0.65])

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('200K, flake 1')

print(fg6,strcat(figurepath,'figureS3b.png'),'-dpng');

%%
%Figure S3c
%calibrate the axes from V --> um
%plot the map of the valley coherence
%300K, flake 1

axisX = linspace(stepX300K*info300K_flake1valley.sample_x595_2(1)/10,stepX300K*info300K_flake1valley.sample_x595_2(end-1)/10,length(info300K_flake1valley.sample_x595_2)-1);
axisY = linspace(stepY300K*info300K_flake1valley.sample_y595_2(1)/10,stepY300K*info300K_flake1valley.sample_y595_2(end)/10,length(info300K_flake1valley.sample_y595_2));

fg7 = figure(7); clf(fg7); set(gcf,'Color','w');

imagesc(axisX,axisY,info300K_flake1valley.ValleyPol595_flake1_fit(:,1:end-1))

cl=colorbar; colormap(vivid(cmap, [.5 .5]));  caxis([0.1 0.45])

xlabel('X (um)'); set(gca,'Xdir','reverse')
ylabel('Y (um)'); set(gca,'Ydir','normal')
title('300K, flake 1')

print(fg7,strcat(figurepath,'figureS3c.png'),'-dpng');






